==> manga_notifier-0.2.0-py2.py3-none-any.whl: manga_notifier/mangastream.py <==


import requests
from lxml import html

from meow import Meow

MANGASTREAM_URL = "http://www.mangastream.com"
MANGASTREAM_LIST_URL = "http://mangastream.com/manga"

def generate_html(url):
    response = requests.get(url)
    if response.ok:
        return response.content


def get_new_release():

    content = generate_html(MANGASTREAM_URL)
    root = html.fromstring(content)

    for elem in root.xpath('//div[@class="side-nav hidden-xs"]/ul[@class="new-list"]/li'):
        for a in elem.xpath('./a'):
            name = a.xpath('text()')[0].strip()
            chapter = a.find('strong').text.strip()
            title = a.find('em').text.strip()
            url = a.attrib['href'].strip()

            yield (name, chapter, title, url)

def get_all_manga():

    content = generate_html(MANGASTREAM_LIST_URL)
    root = html.fromstring(content)
    db = {}

    for table in root.xpath('//table[@class="table table-striped"]'):
        for tr in table.xpath('//tr')[1:]:
            name = tr.xpath("./td/strong/a/text()")
            chapter = tr.xpath("./td/a/text()")
            db[name[0]] = chapter[0]

    return db

def check_release(manga):

    content = generate_html(MANGASTREAM_URL)
    new = {}
    for k, v in manga.items():
        for release in get_new_release(content):
            if release[0] == k and int(release[1]) > int(v):
                Meow.meow("Chapter {} is OUT".format(release[1]), title=release[0], open=release[3])
                new[release[0]] = int(release[1])

    return new

if __name__ == "__main__":

    content = generate_html(MANGASTREAM_URL)

    for data in get_new_release(content):
        print("url=({})".format(data[3]))

==> manga_notifier-0.2.1-py2.py3-none-any.whl: manga_notifier/mangastream.py <==


import requests
from lxml import html

from meow import Meow

MANGASTREAM_URL = "http://www.mangastream.com"
MANGASTREAM_LIST_URL = "http://mangastream.com/manga"

def generate_html(url):
    response = requests.get(url)
    if response.ok:
        return response.content


def get_new_release():

    content = generate_html(MANGASTREAM_URL)
    root = html.fromstring(content)

    for elem in root.xpath('//div[@class="side-nav hidden-xs"]/ul[@class="new-list"]/li'):
        for a in elem.xpath('./a'):
            name = a.xpath('text()')[0].strip()
            chapter = a.find('strong').text.strip()
            title = a.find('em').text.strip()
            url = a.attrib['href'].strip()

            yield (name, chapter, title, url)

def get_all_manga():

    content = generate_html(MANGASTREAM_LIST_URL)
    root = html.fromstring(content)
    db = {}

    for table in root.xpath('//table[@class="table table-striped"]'):
        for tr in table.xpath('//tr')[1:]:
            name = tr.xpath("./td/strong/a/text()")
            chapter = tr.xpath("./td/a/text()")
            db[name[0]] = chapter[0]

    return db

def check_release(manga):

    new = {}
    for k, v in manga.items():
        for release in get_new_release():
            if release[0] == k and int(release[1]) > int(v):
                Meow.meow("Chapter {} is OUT".format(release[1]), title=release[0], open=release[3])
                new[release[0]] = int(release[1])

    return new

if __name__ == "__main__":

    content = generate_html(MANGASTREAM_URL)

    for data in get_new_release(content):
        print("url=({})".format(data[3]))
